@@ -2,9 +2,19 @@ from skimage.color import rgb2gray
 from skimage.io import imread
 from PIL import Image
 from PIL.MpoImagePlugin import MpoImageFile
-from cairosvg import svg2png
+try:
+    from cairosvg import svg2png
+except ImportError:
+    pass
+from six import string_types, text_type
 from io import BytesIO
 import numpy as np
+import xml.etree
+import xml.etree.ElementTree
+
+
+class CorruptImageError(RuntimeError):
+    pass
 
 
 class ImageSignature(object):
@@ -218,19 +228,23 @@ class ImageSignature(object):
             try:
                 img = Image.open(BytesIO(image_or_path))
             except IOError:
-                #  could be an svg, attempt to convert
-                img = Image.open(BytesIO(svg2png(image_or_path)))
+                # could be an svg, attempt to convert
+                try:
+                    img = Image.open(BytesIO(svg2png(image_or_path)))
+                except (NameError, xml.etree.ElementTree.ParseError):
+                    raise CorruptImageError()
             img = img.convert('RGB')
             return rgb2gray(np.asarray(img, dtype=np.uint8))
-        elif type(image_or_path) is str:
-            return imread(image_or_path, as_grey=True)
+        elif type(image_or_path) in string_types or \
+             type(image_or_path) is text_type:
+            return imread(image_or_path, as_gray=True)
         elif type(image_or_path) is bytes:
             try:
                 img = Image.open(image_or_path)
                 arr = np.array(img.convert('RGB'))
             except IOError:
-                #  try again due to PIL weirdness
-                return imread(image_or_path, as_grey=True)
+                # try again due to PIL weirdness
+                return imread(image_or_path, as_gray=True)
             if handle_mpo:
                 # take the first images from the MPO
                 if arr.shape == (2,) and isinstance(arr[1].tolist(), MpoImageFile):
@@ -392,11 +406,11 @@ class ImageSignature(object):
         avg_grey = np.zeros((x_coords.shape[0], y_coords.shape[0]))
 
         for i, x in enumerate(x_coords):        # not the fastest implementation
-            lower_x_lim = max([x - P/2, 0])
-            upper_x_lim = min([lower_x_lim + P, image.shape[0]])
+            lower_x_lim = int(max([x - P/2, 0]))
+            upper_x_lim = int(min([lower_x_lim + P, image.shape[0]]))
             for j, y in enumerate(y_coords):
-                lower_y_lim = max([y - P/2, 0])
-                upper_y_lim = min([lower_y_lim + P, image.shape[1]])
+                lower_y_lim = int(max([y - P/2, 0]))
+                upper_y_lim = int(min([lower_y_lim + P, image.shape[1]]))
 
                 avg_grey[i, j] = np.mean(image[lower_x_lim:upper_x_lim,
                                         lower_y_lim:upper_y_lim])  # no smoothing here as in the paper
