@@ -13,7 +13,7 @@ class SignatureDatabaseBase(object):
 
     """
 
-    def search_single_record(self, rec):
+    def search_single_record(self, rec, pre_filter=None):
         """Search for a matching image record.
 
         Must be implemented by derived class.
@@ -48,6 +48,12 @@ class SignatureDatabaseBase(object):
 
                  The number of simple words corresponds to the attribute N
 
+            pre_filter (dict): a filter to be applied by the concrete implementation
+                   before applying the matching strategy
+
+                For example:
+                    { "term": {  "image.metadata.category": "art" } }
+
         Returns:
             a formatted list of dicts representing matches.
 
@@ -202,7 +208,7 @@ class SignatureDatabaseBase(object):
         rec = make_record(path, self.gis, self.k, self.N, img=img, bytestream=bytestream, metadata=metadata)
         self.insert_single_record(rec, refresh_after=refresh_after)
 
-    def search_image(self, path, all_orientations=False, bytestream=False):
+    def search_image(self, path, all_orientations=False, bytestream=False, pre_filter=None):
         """Search for matches
 
         Args:
@@ -213,7 +219,8 @@ class SignatureDatabaseBase(object):
             bytestream (Optional[boolean]): will the image be passed as raw bytes?
                 That is, is the 'path_or_image' argument an in-memory image?
                 (default False)
-
+            pre_filter (Optional[dict]): filters list before applying the matching algorithm
+                (default None)
         Returns:
             a formatted list of dicts representing unique matches, sorted by dist
 
@@ -265,7 +272,7 @@ class SignatureDatabaseBase(object):
             # generate the signature
             transformed_record = make_record(transformed_img, self.gis, self.k, self.N)
 
-            l = self.search_single_record(transformed_record)
+            l = self.search_single_record(transformed_record, pre_filter=pre_filter)
             result.extend(l)
 
         ids = set()
@@ -429,7 +436,7 @@ def words_to_int(word_array):
     coding_vector = 3**np.arange(width)
 
     # The 'plus one' here makes all digits positive, so that the
-    # integer represntation is strictly non-negative and unique
+    # integer representation is strictly non-negative and unique
     return np.dot(word_array + 1, coding_vector)
 
 
